@@ -5,14 +5,21 @@ import subprocess
 
 from nile import deployments
 from nile.common import GATEWAYS, prepare_params
+from nile.core import account
+from nile.utils import hex_address
 
 
 def call_or_invoke(
     contract, type, method, params, network, signature=None, max_fee=None
 ):
     """Call or invoke functions of StarkNet smart contracts."""
-    address, abi = next(deployments.load(contract, network))
+    if isinstance(contract, account.Account):
+        address = contract.address
+        abi = contract.abi_path
+    else:
+        address, abi = next(deployments.load(contract, network))
 
+    address = hex_address(address)
     command = [
         "starknet",
         type,
