@@ -15,8 +15,10 @@ def declare(contract_name, network, alias=None, overriding_path=None):
 
     output = run_command(contract_name, network, overriding_path, operation="declare")
     class_hash, tx_hash = parse_information(output)
-    logging.info(f"⏳ Declaration of {contract_name} successfully sent at {class_hash}")
-    logging.info(f"🧾 Transaction hash: {tx_hash}")
+    logging.info(
+        f"⏳ Declaration of {contract_name} successfully sent at {hex(class_hash)}"
+    )
+    logging.info(f"🧾 Transaction hash: {hex(tx_hash)}")
 
     deployments.register_class_hash(class_hash, network, alias)
     return class_hash
